# Installation

At the command line if only command line use planned:

```console
❯ pipx install partitionsets
```

At the command line if planning to also use the python API:

```console
❯ python -m pip install partitionsets
```
